use Test2::V0;

use v5.36.0;

package TestMe {
    use Moo;

    has changelog => (
        is => 'ro',
        default => sub {{
             project => { ticket_url => undef },
             releases => [
                 {  },
             ]
        }}
    );

    with  'App::Changelord::Role::GitRepo';
    with 'App::Changelord::Role::ChangeTypes';

}

package TestRepo {
    use Moo;

    sub run(@args) {
        return 'blah blah';
    }
}

my $test = TestMe->new(
    repo => TestRepo->new,
);

like $test->stats => qr/code churn: /;

done_testing;
